<?php

namespace Drupal\shy_one_time\Controller;

use Drupal\passwordless\Controller\PasswordlessUserController;
use Jaybizzle\CrawlerDetect\CrawlerDetect;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;

/**
 * ShyPasswordlessController class extends PasswordlessUserController.
 *
 * If the module 'Passwordless' is installed, the controller of the module
 * is used. The module rewrites the format and delivery of the one-time link.
 */
class ShyPasswordlessController extends PasswordlessUserController {

  /**
   * Request check via CrawlerDetect.
   *
   * Check if the url is retrieved by spider, crawler or bot. If this is the
   * case, access is denied, but the url remains valid for normal access by a
   * user. In this case, specifically for module Passwordless, if it is
   * installed.
   *
   * In order to never disclose a reset link via a referrer header this
   * controller must always return a redirect response.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   Request access.
   * @param int $uid
   *   Unique user ID.
   * @param int $timestamp
   *   Current timestamp.
   * @param string $hash
   *   Hash value as parameter.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The access results.
   */
  public function resetPass(Request $request, $uid, $timestamp, $hash): RedirectResponse {
    if ((new CrawlerDetect())->isCrawler()) {
      throw new AccessDeniedHttpException();
    }
    return parent::resetPass($request, $uid, $timestamp, $hash);
  }

}
